@@ -15,10 +15,11 @@
 #' @import miniUI
 
 rainette2_explor <- function(res, dtm = NULL, corpus_src = NULL) {
-
   ## Error if no dtm
   if (is.null(dtm)) {
-    stop("rainette2_explor must be called with a result object and its associated dtm.")
+    stop(
+      "rainette2_explor must be called with a result object and its associated dtm."
+    )
   }
 
   ## Stop if res comes from rainette instead of rainette2
@@ -40,7 +41,6 @@ rainette2_explor <- function(res, dtm = NULL, corpus_src = NULL) {
   dtm_name <- deparse(substitute(dtm))
   max_n_groups <- max(res$k, na.rm = TRUE)
 
-
   ui <- miniPage(
     gadgetTitleBar("Clustering exploration", left = NULL),
     tags$head(tags$style(rainette_explor_css())),
@@ -55,16 +55,27 @@ rainette2_explor <- function(res, dtm = NULL, corpus_src = NULL) {
               flex = c(10, 1),
               id = "side",
               div(
-                sliderInput("k",
+                sliderInput(
+                  "k",
                   label = "Number of clusters",
                   value = max_n_groups,
-                  min = 2, max = max_n_groups, step = 1
+                  min = 2,
+                  max = max_n_groups,
+                  step = 1
                 ),
-                selectInput("criterion", "Partition criterion",
+                selectInput(
+                  "criterion",
+                  "Partition criterion",
                   choices = criterion_choices
                 ),
-                checkboxInput("complete_km", label = "Complete with k-nearest neighbours", value = FALSE),
-                selectInput("measure", "Statistics",
+                checkboxInput(
+                  "complete_km",
+                  label = "Complete with k-nearest neighbours",
+                  value = FALSE
+                ),
+                selectInput(
+                  "measure",
+                  "Statistics",
                   choices = c(
                     "Keyness - Chi-squared" = "chi2",
                     "Keyness - Likelihood ratio" = "lr",
@@ -72,21 +83,38 @@ rainette2_explor <- function(res, dtm = NULL, corpus_src = NULL) {
                     "Frequency - Documents proportion" = "docprop"
                   )
                 ),
-                numericInput("n_terms",
+                numericInput(
+                  "n_terms",
                   label = "Number of terms to display",
-                  value = 20, min = 5, max = 30, step = 1
+                  value = 20,
+                  min = 5,
+                  max = 30,
+                  step = 1
                 ),
                 conditionalPanel(
                   "input.measure != 'docprop'",
-                  checkboxInput("same_scales", label = "Force same scales", value = TRUE)
+                  checkboxInput(
+                    "same_scales",
+                    label = "Force same scales",
+                    value = TRUE
+                  )
                 ),
-                checkboxInput("show_negative", label = "Show negative values", value = FALSE),
-                sliderInput("text_size",
+                checkboxInput(
+                  "show_negative",
+                  label = "Show negative values",
+                  value = FALSE
+                ),
+                sliderInput(
+                  "text_size",
                   label = "Text size",
-                  value = 12, min = 6, max = 20, step = 1
+                  value = 12,
+                  min = 6,
+                  max = 20,
+                  step = 1
                 )
               ),
-              actionButton("get_r_code",
+              actionButton(
+                "get_r_code",
                 class = "btn-success",
                 icon = icon("code"),
                 label = gettext("Get R code")
@@ -99,8 +127,9 @@ rainette2_explor <- function(res, dtm = NULL, corpus_src = NULL) {
           )
         )
       ),
-          miniTabPanel(
-        "Cluster documents", icon = shiny::icon("file-alt"),
+      miniTabPanel(
+        "Cluster documents",
+        icon = shiny::icon("file-alt"),
         miniContentPanel(
           docs_sample_ui("rainette2", res)
         )
@@ -109,19 +138,33 @@ rainette2_explor <- function(res, dtm = NULL, corpus_src = NULL) {
   )
 
   server <- function(input, output, session) {
-
     plot_code <- reactive({
-      code <- paste0("rainette2_plot(\n  ", res_name, ", ", dtm_name, ", k = ", input$k,
-        ",\n  criterion = \"", input$criterion, "\"",
-        ",\n  n_terms = ", input$n_terms,
-        ",\n  free_scales = ", !input$same_scales,
-        ",\n  measure = \"", input$measure, "\"",
-        ",\n  show_negative = ", input$show_negative,
-        ifelse(input$complete_km,
+      code <- paste0(
+        "rainette2_plot(\n  ",
+        res_name,
+        ", ",
+        dtm_name,
+        ", k = ",
+        input$k,
+        ",\n  criterion = \"",
+        input$criterion,
+        "\"",
+        ",\n  n_terms = ",
+        input$n_terms,
+        ",\n  free_scales = ",
+        !input$same_scales,
+        ",\n  measure = \"",
+        input$measure,
+        "\"",
+        ",\n  show_negative = ",
+        input$show_negative,
+        ifelse(
+          input$complete_km,
           paste0(",\n  complete_groups = \"", input$complete_km, "\""),
           ""
         ),
-        ifelse(input$text_size != "10",
+        ifelse(
+          input$text_size != "10",
           paste0(",\n  text_size = ", input$text_size),
           ""
         ),
@@ -135,14 +178,24 @@ rainette2_explor <- function(res, dtm = NULL, corpus_src = NULL) {
       if (input$complete_km) {
         out <- "group <- "
       }
-      out <- paste0(out, "cutree_rainette2(", res_name,
-        ", k = ", input$k,
-        ", criterion = \"", input$criterion, "\"",
-        ")")
+      out <- paste0(
+        out,
+        "cutree_rainette2(",
+        res_name,
+        ", k = ",
+        input$k,
+        ", criterion = \"",
+        input$criterion,
+        "\"",
+        ")"
+      )
       if (input$complete_km) {
         out <- paste0(
-          out, "\n",
-          "rainette2_complete_groups(", dtm_name, ", groups)"
+          out,
+          "\n",
+          "rainette2_complete_groups(",
+          dtm_name,
+          ", groups)"
         )
       }
       out
@@ -164,12 +217,16 @@ rainette2_explor <- function(res, dtm = NULL, corpus_src = NULL) {
     observeEvent(input$get_r_code, {
       code <- generate_code()
       showModal(modalDialog(
-        title = gettext("Export R code"), size = "l",
-        HTML(paste0("Code to generate the current plot and compute groups :",
+        title = gettext("Export R code"),
+        size = "l",
+        HTML(paste0(
+          "Code to generate the current plot and compute groups :",
           "<pre><code>",
           paste(highr::hi_html(code), collapse = "\n"),
-          "</code></pre>")),
-        easyClose = TRUE))
+          "</code></pre>"
+        )),
+        easyClose = TRUE
+      ))
     })
 
     current_k <- shiny::reactive(input$k)
@@ -179,14 +236,15 @@ rainette2_explor <- function(res, dtm = NULL, corpus_src = NULL) {
     observeEvent(input$done, {
       ## Generate code
       code <- generate_code()
-      out <- paste0("\n-------- Start exported code --------\n\n",
-                    paste(code, collapse = "\n"),
-                    "\n\n--------- End exported code ---------\n")
+      out <- paste0(
+        "\n-------- Start exported code --------\n\n",
+        paste(code, collapse = "\n"),
+        "\n\n--------- End exported code ---------\n"
+      )
       cat(out)
       shiny::stopApp()
     })
   }
 
   shiny::runGadget(ui, server)
-
-}
\ No newline at end of file
+}
