@@ -29,18 +29,21 @@
 #' @import miniUI
 
 rainette_explor <- function(res, dtm = NULL, corpus_src = NULL) {
-
   ## Check for res, dtm and corpus_src values and consistency
   if (is.null(dtm)) {
-    stop("rainette_explor must be called with a result object and its associated dtm.")
+    stop(
+      "rainette_explor must be called with a result object and its associated dtm."
+    )
   }
   if (!is.null(corpus_src) && ndoc(corpus_src) != ndoc(dtm)) {
-      stop("corpus_src and dtm must have the same number of documents.")
+    stop("corpus_src and dtm must have the same number of documents.")
   }
 
   ## If res is a rainette2 result, launch rainette2_explor
   if (inherits(res, "rainette2")) {
-    stop("trying to use rainette_explor() on a rainette2 result object. Use rainette2_explor() instead.")
+    stop(
+      "trying to use rainette_explor() on a rainette2 result object. Use rainette2_explor() instead."
+    )
   }
 
   if (length(res$group) != ndoc(dtm)) {
@@ -56,7 +59,8 @@ rainette_explor <- function(res, dtm = NULL, corpus_src = NULL) {
     tags$head(tags$style(rainette_explor_css())),
     miniTabstripPanel(
       miniTabPanel(
-        "Summary", icon = shiny::icon("chart-bar"),
+        "Summary",
+        icon = shiny::icon("chart-bar"),
         miniContentPanel(
           fillRow(
             flex = c(1, 3),
@@ -64,12 +68,17 @@ rainette_explor <- function(res, dtm = NULL, corpus_src = NULL) {
               flex = c(10, 1),
               id = "side",
               div(
-                sliderInput("k",
+                sliderInput(
+                  "k",
                   label = "Number of clusters",
                   value = max_n_groups,
-                  min = 2, max = max_n_groups, step = 1
+                  min = 2,
+                  max = max_n_groups,
+                  step = 1
                 ),
-                selectInput("measure", "Statistics",
+                selectInput(
+                  "measure",
+                  "Statistics",
                   choices = c(
                     "Keyness - Chi-squared" = "chi2",
                     "Keyness - Likelihood ratio" = "lr",
@@ -77,21 +86,38 @@ rainette_explor <- function(res, dtm = NULL, corpus_src = NULL) {
                     "Frequency - Documents proportion" = "docprop"
                   )
                 ),
-                numericInput("n_terms",
+                numericInput(
+                  "n_terms",
                   label = "Number of terms to display",
-                  value = 20, min = 5, max = 30, step = 1
+                  value = 20,
+                  min = 5,
+                  max = 30,
+                  step = 1
                 ),
                 conditionalPanel(
                   "input.measure != 'docprop'",
-                  checkboxInput("same_scales", label = "Force same scales", value = TRUE)
+                  checkboxInput(
+                    "same_scales",
+                    label = "Force same scales",
+                    value = TRUE
+                  )
                 ),
-                checkboxInput("show_negative", label = "Show negative values", value = FALSE),
-                sliderInput("text_size",
+                checkboxInput(
+                  "show_negative",
+                  label = "Show negative values",
+                  value = FALSE
+                ),
+                sliderInput(
+                  "text_size",
                   label = "Text size",
-                  value = 12, min = 6, max = 20, step = 1
+                  value = 12,
+                  min = 6,
+                  max = 20,
+                  step = 1
                 )
               ),
-              actionButton("get_r_code",
+              actionButton(
+                "get_r_code",
                 class = "btn-success",
                 icon = icon("code"),
                 label = gettext("Get R code")
@@ -105,7 +131,8 @@ rainette_explor <- function(res, dtm = NULL, corpus_src = NULL) {
         )
       ),
       miniTabPanel(
-        "Cluster documents", icon = shiny::icon("file-alt"),
+        "Cluster documents",
+        icon = shiny::icon("file-alt"),
         miniContentPanel(
           docs_sample_ui("rainette1", res)
         )
@@ -116,15 +143,26 @@ rainette_explor <- function(res, dtm = NULL, corpus_src = NULL) {
   server <- function(input, output, session) {
     plot_code <- reactive({
       code <- paste0(
-          "rainette_plot(\n  ", res_name, ", ", dtm_name, ", k = ", input$k,
-          ",\n  n_terms = ", input$n_terms,
-          ",\n  free_scales = ", !input$same_scales,
-          ",\n  measure = \"", input$measure, "\"",
-          ",\n  show_negative = ", input$show_negative,
-          ifelse(input$text_size != "10",
-            paste0(",\n  text_size = ", input$text_size),
-            ""
-          ),
+        "rainette_plot(\n  ",
+        res_name,
+        ", ",
+        dtm_name,
+        ", k = ",
+        input$k,
+        ",\n  n_terms = ",
+        input$n_terms,
+        ",\n  free_scales = ",
+        !input$same_scales,
+        ",\n  measure = \"",
+        input$measure,
+        "\"",
+        ",\n  show_negative = ",
+        input$show_negative,
+        ifelse(
+          input$text_size != "10",
+          paste0(",\n  text_size = ", input$text_size),
+          ""
+        ),
         "\n)"
       )
       code
@@ -132,8 +170,11 @@ rainette_explor <- function(res, dtm = NULL, corpus_src = NULL) {
 
     cutree_code <- reactive({
       paste0(
-        "cutree_rainette(", res_name,
-        ", k = ", input$k, ")"
+        "cutree_rainette(",
+        res_name,
+        ", k = ",
+        input$k,
+        ")"
       )
     })
 
@@ -153,7 +194,8 @@ rainette_explor <- function(res, dtm = NULL, corpus_src = NULL) {
     observeEvent(input$get_r_code, {
       code <- generate_code()
       showModal(modalDialog(
-        title = gettext("Export R code"), size = "l",
+        title = gettext("Export R code"),
+        size = "l",
         HTML(paste0(
           "Code to generate the current plot and compute groups :",
           "<pre><code>",
@@ -182,6 +224,7 @@ rainette_explor <- function(res, dtm = NULL, corpus_src = NULL) {
   }
 
   shiny::runGadget(
-    ui, server
+    ui,
+    server
   )
 }
