@@ -29,8 +29,11 @@ split_segments <- function(obj, segment_size = 40, segment_size_window = NULL) {
 ##' @import quanteda
 ##' @importFrom purrr map_chr
 
-
-split_segments.character <- function(obj, segment_size = 40, segment_size_window = NULL) {
+split_segments.character <- function(
+  obj,
+  segment_size = 40,
+  segment_size_window = NULL
+) {
   ## Tokenize into words
   words <- as.character(quanteda::tokens(obj, what = "fastestword"))
 
@@ -39,7 +42,11 @@ split_segments.character <- function(obj, segment_size = 40, segment_size_window
 
 
 ## Split a single tokenized document
-split_segments_words <- function(words, segment_size = 40, segment_size_window = NULL) {
+split_segments_words <- function(
+  words,
+  segment_size = 40,
+  segment_size_window = NULL
+) {
   if (inherits(words, "tokens") && length(words) == 1) {
     words <- as.character(words)
   }
@@ -78,25 +85,32 @@ split_segments_words <- function(words, segment_size = 40, segment_size_window =
   split_indices <- append(split_indices, length(words) - sum(split_indices) + 1)
   split_indices <- cumsum(split_indices)
 
-  segments <- purrr::map_chr(seq_len(length(split_indices) - 1), ~ {
-    w <- words[split_indices[.x]:(split_indices[.x + 1] - 1)]
-    paste0(w, collapse = " ")
-  })
+  segments <- purrr::map_chr(
+    seq_len(length(split_indices) - 1),
+    ~ {
+      w <- words[split_indices[.x]:(split_indices[.x + 1] - 1)]
+      paste0(w, collapse = " ")
+    }
+  )
 
   segments
 }
 
 
-
 ##' @rdname split_segments
 ##' @aliases split_segments.Corpus
 ##' @export
 
-
-split_segments.Corpus <- function(obj, segment_size = 40, segment_size_window = NULL) {
+split_segments.Corpus <- function(
+  obj,
+  segment_size = 40,
+  segment_size_window = NULL
+) {
   corpus <- obj
 
-  if (!inherits(corpus, "Corpus")) stop("corpus must be of class Corpus")
+  if (!inherits(corpus, "Corpus")) {
+    stop("corpus must be of class Corpus")
+  }
 
   corpus <- quanteda::corpus(corpus)
   split_segments(corpus, segment_size, segment_size_window)
@@ -108,9 +122,14 @@ split_segments.Corpus <- function(obj, segment_size = 40, segment_size_window =
 ##' @export
 ##' @importFrom purrr map_int
 
-
-split_segments.corpus <- function(obj, segment_size = 40, segment_size_window = NULL) {
-  if (!inherits(obj, "corpus")) stop("obj must be of class corpus")
+split_segments.corpus <- function(
+  obj,
+  segment_size = 40,
+  segment_size_window = NULL
+) {
+  if (!inherits(obj, "corpus")) {
+    stop("obj must be of class corpus")
+  }
 
   tokens <- quanteda::tokens(obj, what = "fastestword")
 
@@ -123,9 +142,14 @@ split_segments.corpus <- function(obj, segment_size = 40, segment_size_window =
 ##' @export
 ##' @importFrom purrr map_int
 
-
-split_segments.tokens <- function(obj, segment_size = 40, segment_size_window = NULL) {
-  if (!inherits(obj, "tokens")) stop("obj must be of class tokens")
+split_segments.tokens <- function(
+  obj,
+  segment_size = 40,
+  segment_size_window = NULL
+) {
+  if (!inherits(obj, "tokens")) {
+    stop("obj must be of class tokens")
+  }
 
   quanteda::docvars(obj, "segment_source") <- quanteda::docnames(obj)
 
@@ -147,7 +171,9 @@ split_segments.tokens <- function(obj, segment_size = 40, segment_size_window =
     dplyr::mutate(text = texts) %>%
     tidyr::unnest("text") %>%
     dplyr::group_by(.data$segment_source) %>%
-    dplyr::mutate(segment_id = paste0(.data$segment_source, "_", seq_len(dplyr::n()))) %>%
+    dplyr::mutate(
+      segment_id = paste0(.data$segment_source, "_", seq_len(dplyr::n()))
+    ) %>%
     quanteda::corpus(
       docid_field = "segment_id",
       text_field = "text"
